# spec file for php-pecl-excimer
#
# Copyright (c) 2021-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-excimer}

%bcond_without      tests

%global pecl_name   excimer
%global ini_name    40-%{pecl_name}.ini
# segfault in test suite
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure


Summary:        Interrupting timer and low-overhead sampling profiler
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.2.2
Release:        2%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        Apache-2.0
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.1
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
Calls a user-defined callback when a one-shot or periodic timer expires.
Also a sampling profiler backend, which aggregates backtraces collected
by a periodic timer.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_EXCIMER_VERSION/{s/.* "//;s/".*$//;p}' php_excimer.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;excimer.default_max_depth = 1000
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --enable-excimer \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-excimer \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}
# erratic results, randomly fails in mock
rm tests/cpu.phpt
# 8.4
rm tests/maxDepth.phpt

OPT="-q -P --show-diff"
%if "%{php_version}" > "7.4"
OPT="$OPT %{?_smp_mflags}"
%endif

# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}/%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
# Upstream test suite  for NTS extension
TEST_PHP_ARGS="-n -d extension=%{buildroot}/%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php $OPT
%endif

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}/%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
# Upstream test suite  for ZTS extension
TEST_PHP_ARGS="-n -d extension=%{buildroot}/%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php $OPT
%endif
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Oct  1 2024 Remi Collet <remi@remirepo.net> - 1.2.2-2
- ignore 1 test failing with 8.4

* Wed Jul 31 2024 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2
- drop patch merged upstream

* Fri Jul 12 2024 Remi Collet <remi@remirepo.net> - 1.2.1-2
- add patch for PHP 8.4 from
  https://github.com/wikimedia/mediawiki-php-excimer/pull/8

* Thu Feb 29 2024 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1

* Wed Feb 28 2024 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 1.1.1-2
- build out of sources tree

* Tue Mar 14 2023 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1
- drop patch merged upstream

* Fri Mar  3 2023 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- fix build with PHP <= 7.3 using patch from
  https://github.com/wikimedia/mediawiki-php-excimer/pull/5

* Fri Aug  5 2022 Remi Collet <remi@remirepo.net> - 1.0.4-2
- cleanup

* Mon May  9 2022 Remi Collet <remi@remirepo.net> - 1.0.4-1
- update to 1.0.4
- drop patch merged upstream

* Wed May  4 2022 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3
- fix build with PHP 7.1 using patch from
  https://github.com/wikimedia/php-excimer/pull/4

* Tue Oct 19 2021 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2
- drop patches merged upstream

* Wed Oct  6 2021 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- drop patch merged upstream
- add patch for PHP 8.1 from
  https://github.com/wikimedia/php-excimer/pull/2
- display extension version in phpinfo from
  https://github.com/wikimedia/php-excimer/pull/3
- enable ZTS build

* Tue Mar  2 2021 Remi Collet <remi@remirepo.net> - 1.0.0-1
- initial package
- add build fix with PHP 8 from
  https://github.com/wikimedia/php-excimer/pull/1
